/*
	CALC_SN_WEALTH.DO
	------------------
	Constructs mean wealth/expenditure of social network contacts
	
	Run after characteristics_gen.do
	Run getinvars2.do to create any _in variables before starting
*/

clear
clear matrix
clear mata
#delimit ;
set mem 100m;
set matsize 5000;
set more 1;

chdir "~/Documents/Ghana/2009/";
local tmppath = "Constructed Data/Temp/";


/* Program to adjust household numbers for duplicate widows */
/* ie, we don't want to aggregate data across hh splits */
cap program drop adjhhno;
program define adjhhno;
	version 7.0;
	syntax varlist, Village(string);
	tokenize `varlist';
	di "Village is " "`village'";
	if "`village'" == "Darmang" { 
		replace `1' = `1' + 0.1 if `1'==13 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==46 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==50 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==51 & `2'==101;
		replace `1' = `1' + 0.2 if `1'==51 & `2'==201;
		replace `1' = `1' + 0.1 if `1'==52 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==54 & `2'==101;
	};
	else if "`village'" == "Pokrom" {
		replace `1' = `1' + 0.1 if `1'==12 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==27 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==53 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==55 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==62 & `2'==101;
	};
	else if "`village'" == "Oboadaka" {
		replace `1' = `1' + 0.1 if `1'==35 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==38 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==43 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==59 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==65 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==69 & `2'==101;
	};
	else if "`village'" == "Konkonuru" {
		replace `1' = `1' + 0.1 if `1'==1 & `2'==101;
		replace `1' = `1' + 0.2 if `1'==11 & `2'==201;
		replace `1' = `1' + 0.1 if `1'==20 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==46 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==55 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==57 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==59 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==61 & `2'==101;
		replace `1' = `1' + 0.1 if `1'==85 & `2'==101;
		replace `1' = `1' + 0.2 if `1'==85 & `2'==201;
	};
end;


/* Construct SN data files */
local ii = 1;
while `ii'<5 {;
	if `ii'==1 {;
		local village = "Darmang";
	};
	else if `ii'==2 {;
		local village = "Pokrom";
	};
	else if `ii'==3 {;
		local village = "Oboadaka";
	};
	else {;
		local village = "Konkonuru";
	};
	
	
	/* Prepare characteristics_gen file */
	use "`tmppath'/`village'/characteristics_gen.dta", clear;
	ren villageid village;
	
	

	/* Construct asset variables */
	for var susu currency money_owing money_owed bank_bal stocks valuables:
		replace X = 0 if X<0 \
		ren X hhX;
	for var ass_ff_tot ass_ss_tot ass_eq_tot ass_od_tot ass_li_tot ass_og_tot:
		replace X = 0 if X<0 \
		egen hhX=max(X), by(round village hhn);
	for var hhsusu hhcurrency hhmoney_owing hhmoney_owed hhbank_bal hhstocks hhvaluables hhass_ff_tot hhass_ss_tot hhass_eq_tot hhass_od_tot hhass_li_tot hhass_og_tot:
		replace X=0 if X==.;
	gen ass_liq = hhsusu + hhcurrency + hhmoney_owed - hhmoney_owing + hhbank_bal + hhass_ff_tot + hhass_og_tot + hhass_ss_tot;
	label var ass_liq "Liquid assets";
	gen ass_ill = hhstocks + hhvaluables + hhass_eq_tot + hhass_od_tot + hhass_li_tot;
	label var ass_ill "Illiquid assets";
	
	keep round village hhn id exp_nor exp_tot pcexp_nor pcexp_tot totinc ass_liq ass_ill;
	
	for var exp_nor exp_tot pcexp_nor pcexp_tot totinc ass_liq ass_ill:
		gen X_1 = X if round==1 \
		gen X_2 = X if round==2 \
		gen X_3 = X if round==3 \
		gen X_4 = X if round==4 \
		gen X_5 = X if round==5;
		
	collapse (max) exp_nor_* exp_tot_* pcexp_nor_* pcexp_tot_* totinc_* ass_liq_* ass_ill_*, by(village hhn id);
	
	adjhhno hhn id, v(`village');
	
	ren hhn tgthhn;
	ren id tgtid;
	sort village tgthhn tgtid;
	save tmp, replace;


	use "Final Datasets/Social Networks/`village'.dta", clear;
	
	ren q4 sn_knowsof;
	ren q4_in sn_knownof;
	ren q5 sn_knows;
	ren q5_in sn_known;
	ren q6 sn_rel;
	*ren q6_s sn_rel_s;
	*ren q7 sn_howlong;
	ren q8 sn_strength;
	ren q8_in sn_strength_in;
	*ren q9 sn_speak;
	ren q10 sn_trust;
	ren q10_in sn_trusted;
	ren q11 sn_gave;
	ren q11_in sn_gave_in;
	ren q12 sn_recd;
	ren q12_in sn_recd_in;
	
	adjhhno tgthhn tgtid, v(`village');
	
	save "`tmppath'/`village'/network.dta", replace;
	
	
	/* Merge in chx data on tgthhid */
	ren villageid village;
	sort village tgthhn tgtid hhn id;
	merge village tgthhn tgtid using tmp;
	ta _m; drop _m;
	drop if hhn==. | id==.;


	
	/* Then generate the means or sums of variables */
	/* Only count friends who consider you good or close */
	drop if sn_knows==.;
			
	for var exp_nor_* exp_tot_* pcexp_nor_* pcexp_tot_* totinc_* ass_liq_* ass_ill_*:
			replace X = . if sn_gave!=1 | sn_rel==1 \
			gen rX = X if sn_rel<=11;
	
	for var pcexp_tot_*: gen min_X = X \ gen max_X = X;
	
	
	/* Collapse by hhnid */
	collapse (median) sn_trusted sn_knownof exp_nor_* exp_tot_* pcexp_nor_* pcexp_tot_* totinc_* ass_liq_* ass_ill_*
			 (p33) min_pcexp_tot_*
			 (p67) max_pcexp_tot_*
			 (sum)	sn_knows* sn_known sn_gave* sn_recd*, by(village hhn id);
	expand 5;
	egen round = seq(), by(village hhn id);
	
	
	/* Reconstitute round information */
	foreach X in exp_nor exp_tot pcexp_nor pcexp_tot totinc ass_liq ass_ill min_pcexp_tot max_pcexp_tot {;
		gen `X' = .;
		replace `X' = `X'_1 if round==1;
		replace `X' = `X'_2 if round==2;
		replace `X' = `X'_3 if round==3;
		replace `X' = `X'_4 if round==4;
		replace `X' = `X'_5 if round==5;
	};
		
	drop exp_nor_* exp_tot_* pcexp_nor_* pcexp_tot_* totinc_* ass_liq_* ass_ill_* min_pcexp_tot_* max_pcexp_tot_*;
	
	for var exp_nor exp_tot pcexp_nor pcexp_tot totinc ass_liq ass_ill min_pcexp_tot max_pcexp_tot:
			ren X X_in;
	
	adjhhno hhn id, v(`village');
	
	drop if village==.;
	
	sort round village hhn id;
	save "`tmppath'/`village'/characteristics_sn.dta", replace;
	
	local ii = `ii' + 1;
};


/* Stick all the villages together */
use "`tmppath'/Darmang/characteristics_sn.dta", clear;
append using "`tmppath'/Pokrom/characteristics_sn.dta";
append using "`tmppath'/Oboadaka/characteristics_sn.dta";
append using "`tmppath'/Konkonuru/characteristics_sn.dta";

move round village;
sort round village hhn id;
save "Final Datasets/Social Networks/characteristics_sn.dta", replace;

	
