/*
	CHARACTERISTICS_GEN.DO

	Generate individual characteristics and household size for analysis
	
	Run constructall.do first
*/

clear
#delimit ;
set mem 100m;
set more 1;

chdir "~/Documents/Ghana/2009/";
local tmppath = "Constructed Data/Temp/";

/* Program to adjust household numbers for duplicate widows */
/* ie, we don't want to aggregate data across hh splits */
cap program drop adjhhno;
program define adjhhno;
	version 7.0;
	syntax varlist, title(string);
	tokenize `varlist';
	di "Village is " "`title'";
	di "Variable is " "`1'";	*title argument is village name, variable is id;
	if "`title'" == "Darmang" { 
		replace hhn = hhn + 0.1 if hhn==13 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==46 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==50 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==51 & `1'==101;
		replace hhn = hhn + 0.2 if hhn==51 & `1'==201;
		replace hhn = hhn + 0.1 if hhn==52 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==54 & `1'==101;
	};
	else if "`title'" == "Pokrom" {
		replace hhn = hhn + 0.1 if hhn==12 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==27 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==53 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==55 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==62 & `1'==101;
	};
	else if "`title'" == "Oboadaka" {
		replace hhn = hhn + 0.1 if hhn==35 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==38 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==43 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==59 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==65 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==69 & `1'==101;
	};
	else if "`title'" == "Konkonuru" {
		replace hhn = hhn + 0.1 if hhn==1 & `1'==101;
		replace hhn = hhn + 0.2 if hhn==11 & `1'==201;
		replace hhn = hhn + 0.1 if hhn==20 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==46 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==55 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==57 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==59 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==61 & `1'==101;
		replace hhn = hhn + 0.1 if hhn==85 & `1'==101;
		replace hhn = hhn + 0.2 if hhn==85 & `1'==201;
	};
end;

* Iterate over rounds ;
local ii = 1;
while `ii'<5 {;
	if `ii'==1 {;
		local village = "Darmang";
	};
	else if `ii'==2 {;
		local village = "Pokrom";
	};
	else if `ii'==3 {;
		local village = "Oboadaka";
	};
	else {;
		local village = "Konkonuru";
	};

	local rpath = "Final Datasets/Round 1/Stata//`village'";
	local tmppath = "Constructed Data/Temp//`village'/";

	/* PREPARE GENERAL DATA */

	* Household characteristics ;
	use "`rpath'/HHChar.dta", clear;
	drop if q1==.;
	drop round villageid id;
	foreach var of varlist q1-q11_s {;
		ren `var' hhc_`var';
	};
	sort hhn;
	save "`tmppath'/HHChar.dta", replace;
	
	* Plot data ;
	use "Constructed Data/Temp/Plots.dta", clear;
	adjhhno id, title("`village'");
	keep if village==`ii';
	sort hhn id;
	save "`tmppath'/Plots.dta", replace;

	* Perceptions ;
	use "`rpath'/PerceptionsP1.dta", clear;
	keep hhn id q1 q2 q3 q4 q5 q6 q7 q8 q9 q10 q11 q12;
	foreach var of varlist q1-q12 {;
		ren `var' percep_`var';
	};
	sort hhn id;
	save "`tmppath'/PerceptionsP1.dta", replace;

	use "`rpath'/PerceptionsP2.dta", clear;
	keep hhn id q18 q19 q20 q21 q22 q23;
	foreach var of varlist q18-q23 {;
		replace `var'=. if `var'==6;
		ren `var' percep_`var';
	};
	sort hhn id;
	save "`tmppath'/PerceptionsP2.dta", replace;
	
	* Marital attitudes ;
	use "Final Datasets/Round 3/Stata/`village'/Marital.dta", clear;
	local vars = "q1 q2 q3 q4 q5 q17a q17e q17f";
	keep villageid hhn id `vars';
	foreach var in `vars' {; ren `var' marital_`var'; };
	sort villageid hhn id;
	save "`tmppath'/Marital.dta", replace;
	
	* Family Background ;
	use "Final Datasets/Round 3/Stata/`village'/FamilyP1.dta", clear;
	keep hhn id a_q2a a_q7 a_q8a a_q8cy a_q8cm b_q9m b_q9f;
	ren a_q2a holdsoffice;
	recode holdsoffice 2=0;
	ren a_q7 famregion;
	ren a_q8a firstinvge;
	recode firstinvge 2=0;
	ren b_q9m mothoffice;
	recode mothoffice 2=0;
	ren b_q9f fathoffice;
	recode fathoffice 2=0;
	replace a_q8cm=0 if a_q8cm==99 | a_q8cm==.;
	gen timeinvge = a_q8cy + a_q8cm/12;
	drop a_q8cy a_q8cm;
	sort hhn id;
	save "`tmppath'/FamilyP1.dta", replace;

	use "Final Datasets/Round 3/Stata/`village'/FamilyP2.dta", clear;
	keep hhn id c_q1;
	ren c_q1 fostered;
	recode fostered 2=0;
	sort hhn id;
	save "`tmppath'/FamilyP2.dta", replace;
	
	* Farming practices ;
	use "Final Datasets/Round 4/Stata/`village'/FarmingPracP1.dta", clear;
	gen farms = (index(q1a,"0")!=0);
	gen uses_pest = (q2a==1);
	gen uses_fert = (q2c==1);
	gen grows_pine = (q3d==1);
	label var farms "Farms any crop";
	label var uses_pest "Uses pesticide";
	label var uses_fert "Uses fertilizer";
	label var grows_pine "Grows pineapple";
	keep villageid hhn id farms uses_pest uses_fert grows_pine;
	sort hhn id;
	save "`tmppath'/FarmingPrac.dta", replace;
	
	* Orgs and Coops ;
	use "Constructed Data/Round 2/`village'/Organizations.dta", clear;
	ren q2 org_type;
	keep villageid hhn id org_type;
	ta org_type, gen(org_);
	levelsof org_type, local(levels);
	drop org_type;
	collapse (sum) org_*, by(villageid hhn id);
	local jj = 1;
	foreach l of local levels {;
		local tmp = lower("`l'");
		label var org_`jj' "Member of `tmp'";
		local tmp = word("`tmp'",1);	
		ren org_`jj' org_`tmp';
		local jj = `jj' + 1;
	};
	sort hhn id;
	save "`tmppath'/Organizations.dta", replace;
	
	/* Cooperatives file is ready to merge without modification */

	* Education ;
	use "Final Datasets/Round 5/Stata//`village'/Education.dta", clear;
	sort hhn id;
	replace q1 = q1 + 1 if q1>5;
	replace q1 = 6 if q1==25;
	label define schlevel 0 "None/KG" 1 "Primary 1" 2 "Primary 2" 3 "Primary 3" 4 "Primary 4" 5 "Primary 5" 6 "Primary 6"
			7 "JSS 1" 8 "JSS 2" 9 "JSS 3" 10 "M1" 11 "M2" 12 "M3" 13 "SSS1" 14 "SSS2" 15 "SSS3" 16 "S1" 17 "S2" 18 "S3"
			19 "S4" 20 "S5" 21 "VOC/COMM" 22 "TECHNICAL" 23 "UNIVERSITY";
	label values q1 schlevel;
	ren q1 schlevel;
	replace engscore = 0 if q8==2 | q9==3;
	replace q9 = 3 if q9==. & q8==2;
	replace q2 = 0 if schlevel==0;
	ren q2 yrssch;
	ren q5 ability_twi;
	ren q8 read_eng;
	ren q9 ability_eng;
	collapse schlevel yrssch ability_twi read_eng ability_eng engscore mathscore, by(hhn id);
	sort hhn id;
	save "`tmppath'/Education.dta", replace;
	
	* Social network ;
	use "Final Datasets/Social Networks/`village'.dta", clear;
	adjhhno id, title("`village'");
	sort villageid hhn id;
	collapse (sum) q4 q5 q10 q11 q12 (mean) q4_in q5_in q10_in, by(villageid hhn id);
	ren q4 sn_knowsof;
	ren q5 sn_knows;
	ren q10 sn_trusts;
	ren q11 sn_recd;
	ren q12 sn_gave;
	ren q4_in sn_knownof;
	ren q5_in sn_known;
	ren q10_in sn_trusted;
	sort villageid hhn id;
	
	label var sn_knowsof "No. sample members respondent knows of";
	label var sn_knows "No. sample members respondent knows personally";
	label var sn_trusts "No. sample members respondent trusts";
	label var sn_recd "No. sample members from whom respondent has recd a gift";
	label var sn_gave "No. sample members respondent has given a gift";
	label var sn_knownof "No. sample members who know of respondent";
	label var sn_known "No. sample members who know respondent personally";
	label var sn_trusted "No. sample members who trust respondent";
	
	save "`tmppath'/SNetwork.dta", replace;
	
	
	/* PREPARE ROUND-SPECIFIC DATA */
	
	* Gifts ;
	use "Constructed Data/Round 1/`village'/Gifts.dta", clear;
	append using "Constructed Data/Round 2/`village'/Gifts.dta";
	append using "Constructed Data/Round 3/`village'/Gifts.dta";
	append using "Constructed Data/Round 4/`village'/Gifts.dta";
	append using "Constructed Data/Round 5/`village'/Gifts.dta";
	sort round villageid hhn id;
	save "`tmppath'/Gifts.dta", replace;

	* Intrahousehold transfers ;
	use "Constructed Data/Round 1/`village'/Intrahousehold.dta", clear;
	append using "Constructed Data/Round 2/`village'/Intrahousehold.dta";
	append using "Constructed Data/Round 3/`village'/Intrahousehold.dta";
	append using "Constructed Data/Round 4/`village'/Intrahousehold.dta";
	append using "Constructed Data/Round 5/`village'/Intrahousehold.dta";
	sort round villageid hhn id;
	save "`tmppath'/Intrahousehold.dta", replace;	
	
	* Loans ;
	use "Constructed Data/Round 1/`village'/Loans.dta", clear;
	append using "Constructed Data/Round 2/`village'/Loans.dta";
	append using "Constructed Data/Round 3/`village'/Loans.dta";
	append using "Constructed Data/Round 4/`village'/Loans.dta";
	append using "Constructed Data/Round 5/`village'/Loans.dta";
	sort round villageid hhn id;
	save "`tmppath'/Loans.dta", replace;

	* Income ;
	use "Constructed Data/Round 1/`village'/Totinc.dta", clear;
	append using "Constructed Data/Round 2/`village'/Totinc.dta";
	append using "Constructed Data/Round 3/`village'/Totinc.dta";
	append using "Constructed Data/Round 4/`village'/Totinc.dta";
	append using "Constructed Data/Round 5/`village'/Totinc.dta";
	sort round villageid hhn;
	save "`tmppath'/Income.dta", replace;
	
	* Assets ;
	use "Constructed Data/Round 1/`village'/Assets.dta", clear;
	append using "Constructed Data/Round 2/`village'/Assets.dta";
	append using "Constructed Data/Round 3/`village'/Assets.dta";
	append using "Constructed Data/Round 4/`village'/Assets.dta";
	append using "Constructed Data/Round 5/`village'/Assets.dta";
	sort round villageid hhn;
	save "`tmppath'/Assets.dta", replace;
	
	* Consumption;
	use "Constructed Data/Round 1/`village'/HHExp.dta", clear;
	append using "Constructed Data/Round 2/`village'/HHExp.dta";
	append using "Constructed Data/Round 3/`village'/HHExp.dta";
	append using "Constructed Data/Round 4/`village'/HHExp.dta";
	append using "Constructed Data/Round 5/`village'/HHExp.dta";
	sort round villageid hhn;
	save "`tmppath'/HHExp.dta", replace;
	
	* Sale of farm output ;
	use "Constructed Data/Round 1/`village'/SaleFmOut.dta", clear;
	append using "Constructed Data/Round 2/`village'/SaleFmOut.dta";
	append using "Constructed Data/Round 3/`village'/SaleFmOut.dta";
	append using "Constructed Data/Round 4/`village'/SaleFmOut.dta";
	append using "Constructed Data/Round 5/`village'/SaleFmOut.dta";
	keep round villageid hhn id farm_profit farm_sales farm_revenue farm_expenses;
	sort round villageid hhn id;
	save "`tmppath'/SaleFmOut.dta", replace;
	

	/* COMBINE FILES */
	
	use "`tmppath'/RespondentList.dta", clear;
	drop if dropped==0;
	drop dropped;
	adjhhno id, title("`village'");
	expand 5;
	sort villageid hhn id;
	egen round = seq(), by(villageid hhn id);
	order round;
	
	* Gifts ;
	sort round villageid hhn id;
	merge round villageid hhn id using "`tmppath'/Gifts.dta";
	label var gifts "Total gifts given";
	label var receipts "Total gifts received";
	label var gifts_cash "Total cash gifts given";
	label var gifts_kind "Total in-kind gifts given";
	label var receipts_cash "Total cash gifts received";
	label var receipts_kind "Total in-kind gifts received";
	drop if _m==2; drop _m;
	
	* Intrahousehold transfers ;
	sort round villageid hhn id;
	merge round villageid hhn id using "`tmppath'/Intrahousehold.dta";
	label var chop_curr "Chop money, this week";
	label var chop_norm "Chop money, average week";
	label var gift_cash	"Cash gifts to spouse";
	label var gift_kind	"In-kind gifts to spouse";
	label var gift_bus	"Cash to spouse for business";
	drop if _m==2; drop _m;
	
	* Social network ;
	sort villageid hhn id;
	merge villageid hhn id using "`tmppath'/SNetwork.dta";
	drop if _m==2; drop _m;
	
	* Marital attitudes ;
	sort villageid hhn id;
	merge villageid hhn id using "`tmppath'/Marital.dta";
	drop if _m==2; drop _m;
	
	* Loans ;
	sort round villageid hhn id;
	merge round villageid hhn id using "`tmppath'/Loans.dta";
	drop if _m==2; drop _m;
	
	* Consumption ;
	sort round villageid hhn;
	merge round villageid hhn using "`tmppath'/HHExp.dta";
	drop if _m==2; drop _m;
	
	* Sale of farm output ;
	sort round villageid hhn id;
	merge round villageid hhn id using "`tmppath'/SaleFmOut.dta";
	drop if _m==2; drop _m;

	* Income ;
	sort round villageid hhn;
	merge round villageid hhn using "`tmppath'/Income.dta";
	drop if _m==2; drop _m;
	
	* Assets ;
	sort round villageid hhn;
	merge round villageid hhn using "`tmppath'/Assets.dta";
	drop if _m==2; drop _m;
	
	* Household Characteristics ;
	sort hhn;
	merge hhn using "`tmppath'/HHChar.dta";
	drop if _m==2; drop _m;

	* Education ;
	sort hhn id;
	merge hhn id using "`tmppath'/Education";
	drop if _m==2; drop _m;	

	* Perceptions ;
	sort hhn id;
	merge hhn id using "`tmppath'/PerceptionsP1.dta";
	drop if _m==2; drop _m;	

	sort hhn id;
	merge hhn id using "`tmppath'/PerceptionsP2.dta";
	drop if _m==2; drop _m;	

	* Family background ;
	sort hhn id;
	merge hhn id using "`tmppath'/FamilyP1.dta";
	drop if _m==2; drop _m;	

	sort hhn id;
	merge hhn id using "`tmppath'/FamilyP2.dta";
	drop if _m==2; drop _m;	
	
	* Farming Practices ;
	sort hhn id;
	merge hhn id using "`tmppath'/FarmingPrac.dta";
	drop if _m==2; drop _m;
	
	* Orgs and Coops ;
	sort hhn id;
	merge hhn id using "`tmppath'/Organizations.dta";
	drop if _m==2; drop _m;	
	
	sort hhn id;
	merge hhn id using "Constructed Data/Round 2/`village'/Cooperatives.dta";
	drop if _m==2; drop _m;	
	
	* Plots ;
	sort hhn id;
	merge hhn id using "`tmppath'/Plots.dta";
	drop if _m==2; drop _m;	

	replace area = 0 if area==.;
	replace plots = 0 if plots==.;
	
	* Clean up ;
	duplicates drop;
	drop if round==. | hhn==. | id==.;	
	drop village;
	order round villageid hhn id;
	sort hhn id;
	*save "`tmppath'/AllData.dta", replace;
	save "Constructed Data/Temp//`village'/Characteristics_Gen", replace;

	*erase "`tmppath'/HHChar.dta";
	*erase "`tmppath'/PerceptionsP1.dta";
	*erase "`tmppath'/PerceptionsP2.dta";
	*erase "`tmppath'/Education.dta";
	*erase "`tmppath'/Income.dta";

	local ii = `ii'+1;
};
