/*
	CONSTRUCTALL.DO

	Construct aggregates from core survey

	Instructions:  	Run once for each round (does all four villages).

	Definitions:	rpath - raw data location
			spath - saved data location
			tmppath - temporary folder (should be erased after use)

*/

clear
cap clear matrix
cap clear mata
#delimit ;
set mem 100m;
set more 1;

chdir "~/Documents/Ghana/2009";

local rawpath = "Final Datasets/";
local savepath = "Constructed Data/";

local round = 5;

local ii = 1;
while `ii'< 5 {;

	if `ii'==1 {;
		local village = "Darmang";
		local rpath = "`rawpath'/Round `round'/Stata/Darmang/";
		local spath = "`savepath'/Round `round'/Darmang/";
		local tmppath = "Constructed Data/Temp/Darmang/";
	};
	else if `ii'==2 {;
		local village = "Pokrom";
		local rpath = "`rawpath'/Round `round'/Stata/Pokrom/";
		local spath = "`savepath'/Round `round'/Pokrom/";
		local tmppath = "Constructed Data/Temp/Pokrom/";
	};
	else if `ii'==3 {;
		local village = "Oboadaka";
		local rpath = "`rawpath'/Round `round'/Stata/Oboadaka/";
		local spath = "`savepath'/Round `round'/Oboadaka/";
		local tmppath = "Constructed Data/Temp/Oboadaka/";
	};
	else {;
		local village = "Konkonuru";
		local rpath = "`rawpath'/Round `round'/Stata/Konkonuru/";
		local spath = "`savepath'/Round `round'/Konkonuru/";
		local tmppath = "Constructed Data/Temp/Konkonuru/";
	};

	* Use R1 roster ;
	if `round'==1 {;

		/* Short (individual) roster - this is just to give
			characteristics of living hh members */
		use "`rpath'/RosterP1.dta", clear;
		
		* Clean up errors in file ;
		if `ii'==1 {;
			replace q4 = 2 if hhn==51.1 & id==101;
			drop if id==108 & hhn==13.1;		* Duplicate observation ;
			replace id = 301 if hhn==13.1 & id==100; 	* Renumber new husband so he's not head ;
		};
		
		if `ii'==4 {;
			replace q8 = 1 if hhn==85.1 & id==101;
		};
		
		replace q8 = 1 if id==100 | id==101;
		drop if q8==2 | q8==.;
		ren q4 male;
		gen alive = (q5==1);
		ren q6 age;
		replace age = . if age==99 | age==999;
		ren q12 occ;
		replace occ=. if occ==99 | occ==999;
		ren q10 school;
		keep round villageid hhn id male alive age occ school;
		order round villageid hhn id male alive age occ school;
		sort hhn id;
		save "`tmppath'/RosterP1_short.dta", replace;

		use "`rpath'/RosterP2.dta", clear;
		replace q8 = 1 if id==201;
		drop if q8==2 | q8==.;
		ren q4 male;
		ren q6 age;
		replace age = . if age==99 | age==999;
		ren q12 occ;
		replace occ=. if occ==99 | occ==999;
		ren q10 school;
		keep round villageid hhn id male age occ school;
		order round villageid hhn id male age occ school;
		sort hhn id;
		save "`tmppath'/RosterP2_short.dta", replace;

		use "`rpath'/RosterP3.dta", clear;
		drop if q8==2;
		ren q5 male;
		ren q7 age;
		replace age = . if age==99 | age==999;
		ren q12 occ;
		replace occ=. if occ==99 | occ==999;
		ren q10 school;
		keep round villageid hhn id male age occ school;
		order round villageid hhn id male age occ school;
		sort hhn id;
		save "`tmppath'/RosterP3_short.dta", replace;

		use "`tmppath'/RosterP1_short.dta", clear;
		append using "`tmppath'/RosterP2_short.dta";
		append using "`tmppath'/RosterP3_short.dta";
		sort hhn id;
		save "`spath'/ShortRoster.dta", replace;

		erase "`tmppath'/RosterP1_short.dta";
		erase "`tmppath'/RosterP2_short.dta";
		erase "`tmppath'/RosterP3_short.dta";

		
		/* Roster */
		use "`rpath'/RosterP1.dta", clear;
		gen hhsize1 = (q8==1); replace hhsize1 = 0 if hhsize1==.;
		gen agehead1 = q6 if id==respid;
		gen agespouse1 = q6 if id==101 & id!=respid;
		*replace q6 = . if q6==99 | q6==999;	* This just assumes any missing aged person is an adult ;
		gen adults1 = 0;
		gen kids1 = 0;
		replace adults1 = 1 if q6>12 & q6!=. & q8!=2;
		replace kids1 = 1 if q6<=12 & q6!=. & q8!=2;
		sort hhn;
		collapse (max) agehead1 agespouse1 (sum) hhsize1 adults1 kids1, by(hhn);
		keep hhn agehead1 hhsize1 agespouse1 adults1 kids1;
		sort hhn;
		save "`tmppath'/RosterP1.dta", replace;

		use "`rpath'/RosterP2.dta", clear;
		gen hhsize2 = (q8==1); replace hhsize2 = 0 if hhsize2==.;
		gen agehead2 = q6 if id==respid;
		gen agespouse2 = q6 if id==201 & id!=respid;
		*replace q6 = 40 if q6==99 | q6==999;	* This just assumes any missing aged person is an adult ;
		gen adults2 = 0;
		gen kids2 = 0;
		replace adults2 = 1 if q6>12 & q6!=. & q8!=2;
		replace kids2 = 1 if q6<=12 & q6!=. & q8!=2;
		sort hhn;
		collapse (max) agehead2 agespouse2 (sum) hhsize2 adults2 kids2, by(hhn);
		keep hhn hhsize2 agehead2 agespouse2 adults2 kids2;
		sort hhn;
		save "`tmppath'/RosterP2.dta", replace;

		use "`rpath'/RosterP3.dta", clear;
		gen hhsize3 = (q8==1); replace hhsize3 = 0 if hhsize3==.;
		*replace q7 = 40 if q7==99 | q7==999;	* This just assumes any missing aged person is an adult ;
		gen adults3 = 0;
		gen kids3 = 0;
		replace adults3 = 1 if q7>12 & q7!=. & q8==1;
		replace kids3 = 1 if q7<=12 & q7!=. & q8==1;
		sort round village hhn;
		collapse (sum) hhsize3 adults3 kids3, by(hhn);
		keep hhn hhsize3 adults3 kids3;
		sort hhn;
		save "`tmppath'/RosterP3.dta", replace;

		* Add Roster P4 ;

		sort hhn;
		merge hhn using "`tmppath'/RosterP2.dta"; ta _m; drop _m; sort hhn;
		merge hhn using "`tmppath'/RosterP1.dta"; ta _m; drop _m;

		egen hhsize = rsum(hhsize1 hhsize2 hhsize3);
		egen adults = rsum(adults1 adults2 adults3);
		egen kids = rsum(kids1 kids2 kids3);
		gen agehead = agehead1 if agehead1!=.;					* Set age of head (husb if he responded, o'wise wife) ;
		replace agehead = agehead2 if agehead==.;				* Make second wife the head if there is no first ;
		order hhn hhsize adults kids agehead agespouse1 agespouse2;
		sort hhn;
		save "`spath'/Roster.dta", replace;
	};
	* Otherwise use the R1 data ;
	else {;
		use "`savepath'/Round 1//`village'/Roster.dta", clear;
		save "`spath'/Roster.dta", replace;
	};


	/* Assets */
	use "`rpath'/AssetsP1.dta", clear;
	sort round villageid hhn rowno;
	ren q6 value;
	collapse (max) value, by(round villageid hhn rowno);
	sort hhn rowno;
	save "`tmppath'/AssetsP1_byitem.dta", replace;
	use "`rpath'/AssetsP1.dta", clear;
	sort round village hhn id;
	replace q6 = . if q6==99;
	gen q6_own = q6 if q8==1;
	collapse (sum) q6_own q6, by(round village hhn id);
	ren q6_own ass_ff_own;
	ren q6 ass_ff_tot;
	label var ass_ff_own "Food and farm output, owned by self";
	label var ass_ff_tot "Food and farm output, total";
	sort hhn id;
	save "`tmppath'/AssetsP1.dta", replace;

	use "`rpath'/AssetsP2.dta", clear;
	sort round villageid hhn rowno;
	replace q5 = . if q5==99;
	ren q5 value;
	collapse (max) value, by(round villageid hhn rowno);
	replace rowno = rowno + 15;
	sort hhn rowno;
	save "`tmppath'/AssetsP2_byitem.dta", replace;
	use "`rpath'/AssetsP2.dta", clear;
	sort round village hhn id;
	gen q5_own = q5 if q7==1;
	collapse (sum) q5_own q5, by(round village hhn id);
	ren q5_own ass_ss_own;
	ren q5 ass_ss_tot;
	label var ass_ss_own "Stocks of seeds and planting mtls, owned by self";
	label var ass_ss_tot "Stocks of seeds and planting mtls, total";
	sort hhn id;
	save "`tmppath'/AssetsP2.dta", replace;

	use "`rpath'/AssetsP3.dta", clear;
	sort round villageid hhn rowno;
	replace q5 = . if q5==99;
	ren q5 value;
	collapse (max) value, by(round villageid hhn rowno);
	replace rowno = rowno + 30;
	sort hhn rowno;
	save "`tmppath'/AssetsP3_byitem.dta", replace;
	use "`rpath'/AssetsP3.dta", clear;
	sort round village hhn id;
	gen q5_own = q5 if q7==1;
	collapse (sum) q5_own q5, by(round village hhn id);
	ren q5_own ass_eq_own;
	ren q5 ass_eq_tot;
	label var ass_eq_own "Farm equipment, owned by self";
	label var ass_eq_tot "Farm equipment, total";
	sort hhn id;
	save "`tmppath'/AssetsP3.dta", replace;

	use "`rpath'/AssetsP4.dta", clear;
	sort round villageid hhn rowno;
	replace q4 = . if q4==99;
	ren q3 number;
	ren q4 value;
	collapse (max) number value, by(round villageid hhn rowno);
	replace rowno = rowno + 48;
	sort hhn rowno;
	save "`tmppath'/AssetsP4_byitem.dta", replace;
	use "`rpath'/AssetsP4.dta", clear;
	sort round village hhn id;
	gen q4_own = q4 if q6==1;
	collapse (sum) q4_own q4, by(round village hhn id);
	ren q4_own ass_od_own;
	ren q4 ass_od_tot;
	label var ass_od_own "Other durables, owned by self";
	label var ass_od_tot "Other durables, total";
	sort hhn id;
	save "`tmppath'/AssetsP4.dta", replace;

	use "`rpath'/AssetsP5.dta", clear;
	sort round villageid hhn rowno;
	replace q8 = . if q8==99;
	ren q5 number;
	ren q8 value;
	collapse (max) number value, by(round villageid hhn rowno);
	replace rowno = rowno + 66;
	sort hhn rowno;
	save "`tmppath'/AssetsP5_byitem.dta", replace;
	use "`rpath'/AssetsP5.dta", clear;
	sort round village hhn id;
	gen q8_own = q8 if q6==1;
	collapse (sum) q8_own q8, by(round village hhn id);
	ren q8_own ass_li_own;
	ren q8 ass_li_tot;
	label var ass_li_own "Livestock, owned by self";
	label var ass_li_tot "Livestock, total";
	sort hhn id;
	save "`tmppath'/AssetsP5.dta", replace;

	use "`rpath'/AssetsP6.dta", clear;
	* Skip if questionnaire is empty ;
	qui describe;
	local nobs = r(N);
	* If the questionnaire is nonempty, use it ;
	if `nobs'>0 {;
		drop rowno;
		replace q4 = . if q4==99;
		ren q4 value;
		sort round villageid hhn id;
		collapse (sum) value, by(round villageid hhn id);
		collapse (max) value, by(round villageid hhn);
		gen rowno = 82;
		sort hhn;
		save "`tmppath'/AssetsP6_byitem.dta", replace;
		use "`rpath'/AssetsP6.dta", clear;
		sort round village hhn id;
		gen q4_own = q4 if q6==1;
		collapse (sum) q4_own q4, by(round village hhn id);
		ren q4_own ass_og_own;
		ren q4 ass_og_tot;
		label var ass_og_own "Other goods, owned by self";
		label var ass_og_tot "Other goods, total";
	};
	* Otherwise, create dummy file ;
	else {;
		use "`rpath'/AssetsP5.dta", clear;
		gen tmp = 1;
		collapse (max) tmp, by(round villageid hhn);
		keep round village hhn;
		sort hhn;
		save "`tmppath'/AssetsP6_byitem.dta", replace;
		use "`tmppath'/AssetsP5.dta", clear;
		keep round village hhn id;
	};
	sort hhn id;
	save "`tmppath'/AssetsP6.dta", replace;

	* Generate household totals file (with detail) ;
	use "`rpath'/AssetsP7.dta", clear;
	ren a_q4 value1;
	ren c_q3 value2;
	ren d_q3 value3;
	for var value1 value2 value3: replace X = . if X==99;
	sort hhn;
	collapse (sum) value1 value2 value3, by(round villageid hhn);
	reshape long value, i(round villageid hhn) j(rowno);
	order round villageid hhn rowno value;
	replace rowno = rowno + 82;
	sort hhn;
	save "`tmppath'/AssetsP7_byitem.dta", replace;
	* Now the aggregates ;
	use "`rpath'/AssetsP7.dta", clear;
	sort round village hhn id;
	gen susu = a_q4;
	gen money_owing = c_q3;
	gen money_owed = d_q3;
	collapse (sum) susu money_owing money_owed, by(round village hhn id);
	for var susu money_owing money_owed: replace X = 0 if X==.;
	label var susu "Susu balance";
	label var money_owing "Money held for others";
	label var money_owed "Money held by others";
	sort hhn id;
	save "`tmppath'/AssetsP7.dta", replace;

	use "`rpath'/AssetsP8.dta", clear;
	ren q2 value1;
	ren q4 value2;
	egen value3 = rsum(q9 q10 q11);
	ren q12b value4;
	egen value5 = rsum(q14a q14b);
	for var value1 value2 value3 value4 value5: replace X = . if X==99;
	sort hhn;
	collapse (sum) value1 value2 value3 value4 value5, by(round villageid hhn);
	reshape long value, i(round villageid hhn) j(rowno);
	order round villageid hhn rowno value;
	replace rowno = rowno + 85;
	sort hhn;
	save "`tmppath'/AssetsP8_byitem.dta", replace;
	use "`rpath'/AssetsP8.dta", clear;
	sort round village hhn id;
	gen bank_bal = q2;
	gen stocks = q4;
	egen valuables = rsum(q9 q10);
	qui tostring q12a, replace;
	gen currency = 0;
	replace currency = . if q12a!="";
	replace currency = 0.00311*q12b if q12a=="CFA";
	replace currency = 2.07686*q12b if q12a=="EUR";
	replace currency = 1.40466*q12b if q12a=="USD";
	replace currency = currency + q11 if q11!=. & q11>=0;
	egen building = rsum(q14a q14b);
	for var bank_bal stocks valuables currency building: replace X = 0 if X==99;
	keep round village hhn id bank_bal stocks valuables currency building;
	sort hhn id;
	save "`tmppath'/AssetsP8.dta", replace;

	use "`tmppath'/AssetsP1.dta", clear;
	sort hhn id;
	merge hhn id using "`tmppath'/AssetsP2.dta";
	ta _m; drop _m;
	sort hhn id;
	merge hhn id using "`tmppath'/AssetsP3.dta";
	ta _m; drop _m;
	sort hhn id;
	merge hhn id using "`tmppath'/AssetsP4.dta";
	ta _m; drop _m;
	sort hhn id;
	merge hhn id using "`tmppath'/AssetsP5.dta";
	ta _m; drop _m;
	sort hhn id;
	merge hhn id using "`tmppath'/AssetsP6.dta";
	ta _m; drop _m;
	sort hhn id;
	merge hhn id using "`tmppath'/AssetsP7.dta";
	ta _m; drop _m;
	sort hhn id;
	merge hhn id using "`tmppath'/AssetsP8.dta";
	ta _m; drop _m;
	cap gen ass_og_tot = .;
	sort hhn id;
	collapse (sum) susu currency money_owing money_owed bank_bal stocks valuables building (max) ass_ff_tot ass_ss_tot ass_eq_tot ass_od_tot ass_li_tot ass_og_tot, by(round village hhn);
	label var susu "Susu balances";
	label var bank_bal "Bank balance";
	label var stocks "Value of investments";
	label var valuables "Jewelry and cloth";
	label var currency "Cash (local and foreign) in GHC";
	label var building "Value of building & repairs";
	label var ass_ff_tot "Food and farm output";
	label var ass_ss_tot "Other stocks";
	label var ass_eq_tot "Equipment";
	label var ass_od_tot "Other durables";
	label var ass_li_tot "Livestock";
	label var ass_og_tot "Other goods";
	sort round villageid hhn;
	save "`spath'/Assets.dta", replace;

	use "`tmppath'/AssetsP1_byitem.dta", clear;
	append using "`tmppath'/AssetsP2_byitem.dta", force;
	append using "`tmppath'/AssetsP3_byitem.dta", force;
	append using "`tmppath'/AssetsP4_byitem.dta", force;
	append using "`tmppath'/AssetsP5_byitem.dta", force;
	append using "`tmppath'/AssetsP6_byitem.dta", force;
	append using "`tmppath'/AssetsP7_byitem.dta", force;
	append using "`tmppath'/AssetsP8_byitem.dta", force;

	save "`spath'/Assets_byitem.dta", replace;


	/* Consumption */

	* Consumption Part A ;
	use "`rpath'/ConsumptionP1.dta", clear;
	keep round village hhn id rowno q1 q3 q4 q5 q6 q9;
	replace q5 = . if q5==99;
	replace q6 = . if q6==99;
	replace q9 = . if q9==99;
	ren q1 item;
	ren q3 hh_qty;
	ren q4 hh_unit;
	ren q5 hh_exp;
	gen sf_exp = q6*q9;
	drop q6 q9;
	sort hhn id;
	save "`tmppath'/ConsumptionP1.dta", replace;
	
	use "`rpath'/ConsumptionP2.dta", clear;
	keep round village hhn id rowno q1 q3 q4 q5 q6 q9;
	replace rowno = rowno + 15;
	replace q5 = . if q5==99;
	replace q9 = . if q9==99;
	ren q1 item;
	ren q3 hh_qty;
	ren q4 hh_unit;
	ren q5 hh_exp;
	gen sf_exp = q6*q9;
	drop q6 q9;
	sort hhn id;
	save "`tmppath'/ConsumptionP2.dta", replace;
	
	use "`rpath'/ConsumptionP3.dta", clear;
	keep round village hhn id rowno q1 q3 q4 q5 q6 q9;
	replace rowno = rowno + 30;
	replace q5 = . if q5==99;
	replace q9 = . if q9==99;
	ren q1 item;
	ren q3 hh_qty;
	ren q4 hh_unit;
	ren q5 hh_exp;
	gen sf_exp = q6*q9;
	drop q6 q9;
	sort hhn id;
	save "`tmppath'/ConsumptionP3.dta", replace;

	use "`tmppath'/ConsumptionP1.dta";
	append using "`tmppath'/ConsumptionP2.dta";
	append using "`tmppath'/ConsumptionP3.dta";

	drop if hh_exp==. & sf_exp==.;
	sort round village hhn id rowno;
	collapse (max) hh_exp (sum) sf_exp, by(round village hhn id rowno);

	sort round village hhn id;

	save "`spath'/ConsumptionA.dta", replace;

	* Consumption Part B ;
	use "`rpath'/ConsumptionP4.dta", clear;
	keep round village hhn id rowno q1 q3 q4 q5 q8;
	replace q5 = . if q5==99;
	replace q8 = . if q8==99;
	ren q1 item;
	ren q3 hh_qty;
	ren q4 hh_unit;
	ren q5 hh_exp;
	ren q8 sf_exp;
	sort hhn id;
	save "`tmppath'/ConsumptionP4.dta", replace;
	
	use "`rpath'/ConsumptionP5.dta", clear;
	keep round village hhn id rowno q1 q3 q4 q5 q8;
	replace rowno = rowno + 15;
	replace q5 = . if q5==99;
	replace q8 = . if q8==99;
	ren q1 item;
	ren q3 hh_qty;
	ren q4 hh_unit;
	ren q5 hh_exp;
	ren q8 sf_exp;
	sort hhn id;
	save "`tmppath'/ConsumptionP5.dta", replace;

	use "`tmppath'/ConsumptionP4.dta";
	append using "`tmppath'/ConsumptionP5.dta";

	drop if hh_exp==. & sf_exp==.;
	sort round village hhn id rowno;
	collapse (max) hh_exp (sum) sf_exp, by(round village hhn id rowno);

	sort round village hhn id;

	save "`spath'/ConsumptionB.dta", replace;

	* Consumption Part C ;
	use "`rpath'/ConsumptionP6.dta", clear;
	keep round village hhn id rowno q1 q3 q4 q6;
	replace rowno = rowno;
	replace q4 = . if q4==99;
	replace q6 = . if q6==99;
	ren q1 item;
	ren q3 hh_qty;
	ren q4 hh_exp;
	ren q6 sf_exp;
	sort hhn id;
	save "`tmppath'/ConsumptionP6.dta", replace;
	
	use "`rpath'/ConsumptionP7.dta", clear;
	keep round village hhn id rowno q1 q3 q4 q6;
	replace rowno = rowno + 15;
	replace q4 = . if q4==99;
	replace q6 = . if q6==99;
	ren q1 item;
	ren q3 hh_qty;
	ren q4 hh_exp;
	ren q6 sf_exp;
	sort hhn id;
	save "`tmppath'/ConsumptionP7.dta", replace;

	use "`rpath'/ConsumptionP8.dta", clear;
	keep round village hhn id rowno q1 q3 q4 q6;
	replace rowno = rowno + 30;
	replace q4 = . if q4==99;
	replace q6 = . if q6==99;
	ren q1 item;
	ren q3 hh_qty;
	ren q4 hh_exp;
	ren q6 sf_exp;
	sort hhn id;
	save "`tmppath'/ConsumptionP8.dta", replace;

	use "`tmppath'/ConsumptionP6.dta";
	append using "`tmppath'/ConsumptionP7.dta";
	append using "`tmppath'/ConsumptionP8.dta";

	drop if hh_exp==. & sf_exp==.;
	sort round village hhn id rowno;
	collapse (max) hh_exp (sum) sf_exp, by(round village hhn id rowno);

	sort round village hhn id;

	save "`spath'/ConsumptionC.dta", replace;

	/* To minimize error, allocate the highest reported household expenditure to all hh members, then at
	*  the end we choose either this number or the sum of individual expenses, whichever is largest. */
	recode hh_exp .=0;
	recode sf_exp .=0;
	egen tmp = max(hh_exp), by(round village hhn rowno);
	egen h_expC = mean(tmp), by(round village hhn rowno); * This is so we can sum across hh members without duplicating ;
	ren sf_exp exp;
	
	/* Generate specific variables first, then by category */
	gen exp_school = exp if rowno==1 | rowno==2;
	gen exp_health = exp if rowno==3 | rowno==4;
	gen exp_cloth_adult = exp if rowno==5 | rowno==8;
	gen exp_cloth_child = exp if rowno==6 | rowno==9;
	gen exp_perscare = exp if rowno==12 | rowno==13 | rowno==31;	* Putting haircuts in personal care ;
	gen exp_hhitem = exp if rowno==7 | rowno==10 | rowno==11 | rowno==14 | rowno==15;   * I am including raw cloth in this item ;
	gen exp_pubtran = exp if rowno==16;
	gen exp_vehicle = exp if rowno==17 | rowno==18 | rowno==43 | rowno==44;
	gen exp_entert = exp if rowno==19 | rowno==34;
	gen exp_fuel = exp if (rowno>=20 & rowno<=22) | rowno==25;
	gen exp_equip = exp if rowno==23 | rowno==24 | rowno==28 | rowno==29 | rowno==40 | rowno==41 | rowno==42;
	gen exp_utils = exp if rowno==26 | rowno==27;	* Note I am adding telephone bills AND credit here ;
	gen exp_rent = exp if rowno==30 | rowno==35;
	gen exp_jewel = exp if rowno==33;
	gen exp_cerem = exp if rowno==36 | rowno==37;
	gen exp_lottobac = exp if rowno==38 | rowno==39;
	gen exp_other = exp if rowno==32 | rowno==45;	* Domestic servants here (probably none) ;
	
	/* This code used for Castilla paper only 
	for var exp_*: gen husb_X = X*(id==100);
	for var exp_*: gen wife_X = X*(id!=100);
	
	collapse (sum) h_expC exp_* husb_exp_* wife_exp_*, by(round village hhn);
	*/
	
	/* Used for all papers except Castilla */
	/* exp_asset includes stove/kitchen equip, jewelery, furniture, sewing machine, radio, etc. */
	gen exp_asset = exp if rowno==23 | rowno==24 | rowno==28 | rowno==33 | rowno>=40; recode exp_asset .=0;
	gen h_exp_asset = h_exp if rowno==23 | rowno==24 | rowno==28 | rowno==33 | rowno>=40; recode h_exp_asset .=0;
	gen husb_exp_asset = exp_asset*(id==100);
	gen wife_exp_asset = exp_asset*(id!=100);
	/* exp_abnor includes weddings, dowries, funerals, taxes, repairs/vehicle expenses, school and medical fees */
	gen exp_abnor = exp if rowno<=4 | rowno==15 | rowno==18 | rowno==35 | rowno==36 | rowno==37; recode exp_abnor .=0;
	gen h_exp_abnor = h_exp if rowno<=4 | rowno==15 | rowno==18 | rowno==35 | rowno==36 | rowno==37; recode h_exp_abnor .=0;
	gen husb_exp_abnor = exp_abnor*(id==100);
	gen wife_exp_abnor = exp_abnor*(id!=100);
	/* exp_other includes all else: shoes, clothing, personal care, cleaning items, public transport, books, light, EGW, entertainment
	lottery tickets, vice */
	gen exp_other = exp if rowno>4 & rowno!=15 & rowno!=18 & rowno!=23 & rowno!=24 & rowno!=28 & rowno!=33 & rowno!=35 & rowno!=36 & rowno!=37 & rowno<40; recode exp_other .=0;
	gen h_exp_other = h_exp if rowno>4 & rowno!=15 & rowno!=18 & rowno!=23 & rowno!=24 & rowno!=28 & rowno!=33 & rowno!=35 & rowno!=36 & rowno!=37 & rowno<40; recode h_exp_other .=0;
	gen husb_exp_other = exp_other*(id==100);
	gen wife_exp_other = exp_other*(id!=100);
	gen husb_exp_vice2 = exp*(id==100) if rowno==34 | rowno==38 | rowno==39;
	gen wife_exp_vice2 = exp*(id!=100) if rowno==34 | rowno==38 | rowno==39;
	gen exp_cerem = exp if rowno==36 | rowno==37; recode exp_cerem .=0;
	gen h_exp_cerem = h_exp if rowno==36 | rowno==37; recode h_exp_cerem .=0;
	gen husb_exp_cerem = exp_cerem*(id==100);
	gen wife_exp_cerem = exp_cerem*(id!=100);
	collapse (sum) *exp_asset *exp_abnor *exp_other husb_exp_vice2 wife_exp_vice2 *exp_cerem, by(round village hhn);
	for var exp_asset exp_abnor exp_other exp_cerem: replace X = h_X if h_X > X & h_X!=.;
	
	sort hhn;
	save "`spath'/HHExp_C.dta", replace;

	use "`spath'/ConsumptionB.dta", clear;
	recode hh_exp .=0;
	recode sf_exp .=0;
	egen tmp = max(hh_exp), by(round village hhn rowno);
	egen h_expB = mean(tmp), by(round village hhn rowno); * This is so we can sum across hh members without duplicating ;
	ren sf_exp exp;
	gen husb_exp = exp*(id==100);
	gen wife_exp = exp*(id!=100);	
	collapse (sum) exp h_expB husb_exp wife_exp, by(round village hhn);
	replace exp = h_expB if h_expB>exp & h_expB!=.;
	ren exp exp_farm;
	ren husb_exp husb_exp_farm;
	ren wife_exp wife_exp_farm;
	sort hhn;
	save "`spath'/HHExp_B.dta", replace;

	use "`spath'/ConsumptionA.dta", clear;
	recode hh_exp .=0;
	recode sf_exp .=0;
	egen tmp = max(hh_exp), by(round village hhn rowno);
	egen h_expA = mean(tmp), by(round village hhn rowno); * This is so we can sum across hh members without duplicating ;
	ren sf_exp exp;
	gen husb_exp = exp*(id==100);
	gen wife_exp = exp*(id!=100);
	gen husb_exp_alcrest = husb_exp if rowno==29 | rowno==41;
	gen wife_exp_alcrest = wife_exp if rowno==29 | rowno==41;
	gen husb_exp_vice1 = husb_exp if rowno==29 | rowno==41;	*Alcohol and chop bar meals;
	gen wife_exp_vice1 = wife_exp if rowno==29 | rowno==41;
	collapse (sum) exp h_expA husb_exp wife_exp husb_exp_vice1 wife_exp_vice1 husb_exp_alcrest wife_exp_alcrest, by(round village hhn);
	replace exp = h_expA if h_expA>exp & h_expA!=.;
	ren exp exp_purch;
	ren husb_exp husb_exp_purch;
	ren wife_exp wife_exp_purch;
	sort hhn;
	save "`spath'/HHExp_A.dta", replace;

	merge hhn using "`spath'/HHExp_B.dta"; ta _m; drop _m; sort hhn;
	merge hhn using "`spath'/HHExp_C.dta"; ta _m; drop _m;

	for var _all: recode X .=0;
	
	/* Used for all papers except Castilla */
	gen exp_nor = exp_purch + exp_farm + exp_other;
	gen exp_tot = exp_nor + exp_asset + exp_abnor;
	gen husb_exp_nor = husb_exp_purch + husb_exp_farm + husb_exp_other;
	gen wife_exp_nor = wife_exp_purch + wife_exp_farm + wife_exp_other;
	gen husb_exp_tot = husb_exp_nor + husb_exp_asset + husb_exp_abnor;
	gen wife_exp_tot = wife_exp_nor + wife_exp_asset + wife_exp_abnor;
	gen husb_exp_vice = husb_exp_vice1 + husb_exp_vice2;
	gen wife_exp_vice = wife_exp_vice1 + wife_exp_vice2;
	
	/* Used for Castilla paper only 
	gen exp_alcrest = husb_exp_alcrest + wife_exp_alcrest;
	gen exp_food = exp_purch + exp_farm;
	gen husb_exp_food = husb_exp_purch + husb_exp_farm;
	gen wife_exp_food = wife_exp_purch + wife_exp_farm;
	gen exp_nor = exp_food + exp_perscare + exp_cloth_adult + exp_cloth_child + exp_hhitem + exp_pubtran + exp_entert + exp_fuel + exp_utils + exp_rent + exp_lottobac + exp_alcrest;
	gen exp_abnor = exp_cerem + exp_vehicle + exp_school + exp_health;
	gen exp_asset = exp_equip + exp_jewel;
	gen exp_tot = exp_nor + exp_asset + exp_abnor;
	*/
	
	label var exp_tot "Total expenditure";
	label var exp_food "Food expenditure";
	label var exp_purch "Food purchased";
	label var exp_farm "Food from family farms";
	label var exp_nor "Normal expenditure";
	label var exp_asset "Asset purchases";
	label var exp_abnor "Abnormal expenditure";
	label var exp_alcrest "Alcohol and meals outside";
	label var exp_school "School expenses";
	label var exp_health "Health expenses";
	label var exp_cloth_adult "Clothing for adults";
	label var exp_cloth_child "Clothing for children";
	label var exp_perscare "Personal care";
	label var exp_hhitem "Household items";
	label var exp_pubtran "Public transport";
	label var exp_vehicle "Vehicle expenses";
	label var exp_entert "Entertainment expenses";
	label var exp_fuel "Fuel and light";
	label var exp_equip "Household equipment and appliances";
	label var exp_utils "Utility bills";
	label var exp_rent "Rent and taxes";
	label var exp_jewel "Jewelry purchased";
	label var exp_cerem "Ceremonial expenses";
	label var exp_lottobac "Tobacco and lottery tickets";
	label var exp_other "Other expenses";
	label var exp_alcrest "Alcohol and meals outside";
	
	label var husb_exp_food "Food expenditure (husband)";
	label var husb_exp_purch "Food purchased (husband)";
	label var husb_exp_farm "Food from family farms (husband)";
	label var husb_exp_alcrest "Alcohol and meals outside (husband)";
	label var husb_exp_school "School expenses (husband)";
	label var husb_exp_health "Health expenses (husband)";
	label var husb_exp_cloth_adult "Clothing for adults (husband)";
	label var husb_exp_cloth_child "Clothing for children (husband)";
	label var husb_exp_perscare "Personal care (husband)";
	label var husb_exp_hhitem "Household items (husband)";
	label var husb_exp_pubtran "Public transport (husband)";
	label var husb_exp_vehicle "Vehicle expenses (husband)";
	label var husb_exp_entert "Entertainment expenses (husband)";
	label var husb_exp_fuel "Fuel and light (husband)";
	label var husb_exp_equip "Household equipment and appliances (husband)";
	label var husb_exp_utils "Utility bills (husband)";
	label var husb_exp_rent "Rent and taxes (husband)";
	label var husb_exp_jewel "Jewelry purchased (husband)";
	label var husb_exp_cerem "Ceremonial expenses (husband)";
	label var husb_exp_lottobac "Tobacco and lottery tickets (husband)";
	label var husb_exp_other "Other expenses (husband)";
	label var husb_exp_alcrest "Alcohol and meals outside (husband)";
	
	label var wife_exp_food "Food expenditure (wives)";
	label var wife_exp_purch "Food purchased (wives)";
	label var wife_exp_farm "Food from family farms (wives)";
	label var wife_exp_alcrest "Alcohol and meals outside (wives)";
	label var wife_exp_school "School expenses (wives)";
	label var wife_exp_health "Health expenses (wives)";
	label var wife_exp_cloth_adult "Clothing for adults (wives)";
	label var wife_exp_cloth_child "Clothing for children (wives)";
	label var wife_exp_perscare "Personal care (wives)";
	label var wife_exp_hhitem "Household items (wives)";
	label var wife_exp_pubtran "Public transport (wives)";
	label var wife_exp_vehicle "Vehicle expenses (wives)";
	label var wife_exp_entert "Entertainment expenses (wives)";
	label var wife_exp_fuel "Fuel and light (wives)";
	label var wife_exp_equip "Household equipment and appliances (wives)";
	label var wife_exp_utils "Utility bills (wives)";
	label var wife_exp_rent "Rent and taxes (wives)";
	label var wife_exp_jewel "Jewelry purchased (wives)";
	label var wife_exp_cerem "Ceremonial expenses (wives)";
	label var wife_exp_lottobac "Tobacco and lottery tickets (wives)";
	label var wife_exp_other "Other expenses (wives)";
	label var wife_exp_alcrest "Alcohol and meals outside (wives)";
	
	sort round village hhn;

	/* Generate per capita measures */
	sort hhn;
	merge hhn using "`spath'/Roster.dta";
	cap replace round = `round' if round!=`round';
	ta _m; drop _m;
	*keep round villageid hhn exp_purch exp_farm exp_asset exp_abnor exp_other exp_cerem exp_nor exp_tot husb_exp* wife_exp* hhsize adults kids agehead agespouse1 agespouse2;
	keep round villageid hhn exp_* husb_exp_* wife_exp_* hhsize adults kids agehead agespouse1 agespouse2;
	*gen weight = (adults + 0.3*kids)^0.9;
	gen pcexp_nor = exp_nor/hhsize;
	gen pcexp_tot = exp_tot/hhsize;

	sort hhn;
	
	replace round = `round' if round==.;

	save "`spath'/HHExp.dta", replace;
	erase "`spath'/HHExp_A.dta";
	erase "`spath'/HHExp_B.dta";
	erase "`spath'/HHExp_C.dta";

	/* Income */
	use "`spath'/Income.dta", clear;
	sort hhn;
	egen totinc = rsum(othf_prof oth_inc wages bus_profit bus_cashflow farm_profit);
	collapse (sum) totinc, by(round villageid hhn);
	replace round = `round' if round==.;
	sort hhn;
	save "`spath'/Totinc.dta", replace;

	/* Sale of Farm Output */
	use "`rpath'/SaleFmOutP1.dta", clear;
	ren q7 farm_sales1;
	for var farm_sales1 q17: recode X .=0;
	for var farm_sales1 q17: recode X 99=.;
	gen farm_revenue1 = farm_sales1 - q17;
	replace farm_sales1 = q11 if q11!=.;
	sort hhn id;
	collapse (sum) farm_sales1 farm_revenue1, by(round villageid hhn id);
	sort hhn id;
	keep round villageid hhn id farm_sales1 farm_revenue1;
	save "`tmppath'/SaleFmOutP1.dta", replace;

	use "`rpath'/SaleFmOutP2.dta", clear;
	ren q7 farm_sales2;
	for var farm_sales2 q17: recode X .=0;
	for var farm_sales2 q17: recode X 99=.;
	gen farm_revenue2 = farm_sales2 - q17;
	replace farm_sales2 = q11 if q11!=.;
	replace farm_sales2 = . if q11==99;
	sort hhn id;
	collapse (sum) farm_sales2 farm_revenue2, by(round villageid hhn id);
	sort hhn id;
	keep round villageid hhn id farm_sales2 farm_revenue2;
	save "`tmppath'/SaleFmOutP2.dta", replace;

	* Farm inputs/expenses ;
	use "`rpath'/PlotP5.dta", clear;
	for var q9 q10 q11: replace X = . if X==99;
	egen farm_expenses1 = rsum(q9 q10 q11);
	recode farm_expenses1 .=0;
	sort hhn id;
	collapse (sum) farm_expenses1, by(hhn id);
	save "`tmppath'/FarmExpensesA.dta", replace;

	use "`rpath'/PlotP6.dta", clear;
	recode q6 .=0;
	recode q6 99=.;
	ren q6 farm_expenses2;
	sort hhn id;
	collapse (sum) farm_expenses2, by(hhn id);
	save "`tmppath'/FarmExpensesB.dta", replace;

	use "`tmppath'/SaleFmOutP1.dta", clear;
	sort hhn id;
	merge hhn id using "`tmppath'/SaleFmOutP2.dta";
	drop _m;
	gen farm_sales = farm_sales1+farm_sales2;
	gen farm_revenue = farm_revenue1+farm_revenue2;
	sort hhn id;
	merge hhn id using "`tmppath'/FarmExpensesA.dta";
	drop _m;
	sort hhn id;
	merge hhn id using "`tmppath'/FarmExpensesB.dta";
	drop _m;
	gen farm_expenses = farm_expenses1+farm_expenses2;
	for var farm_sales farm_revenue farm_expenses: recode X .=0;
	gen farm_profit = farm_sales - farm_expenses;
	sort hhn id;
	replace villageid = `ii';
	replace round = `round';
	order round villageid hhn id farm_profit farm_sales farm_revenue farm_expenses;
	save "`spath'/SaleFmOut.dta", replace;
	

	/* Other Income */
	use "`rpath'/OthIncP1.dta", clear;
	for var q2 q3 q4 q8 q9 q10 q11 q12 q13 q14v q15 q16 q17 q18: replace X=. if X==99 | X==999;
	egen bus_revenue = rsum(q15 q16 q17);
	egen bus_expenses = rsum(q3 q4 q8 q9 q10 q12 q13 q14v);
	gen bus_cashflow = q15 + q17 - bus_expenses - q3;			* This is the actual cashflow, since some things (eg stocks are non-cash but included in profit calculations ;
	gen bus_profit = bus_revenue - bus_expenses;
	sort hhn id;
	collapse (sum) bus_profit bus_revenue bus_expenses bus_cashflow, by(round villageid hhn id);
	sort hhn id;
	save "`tmppath'/OthIncP1.dta", replace;

	use "`rpath'/OthIncP2.dta", clear;
	cap recode q9 .=0;
	for var q5 q9: replace X = . if X==99;
	gen wages_rec = q5 - q9;
	ren q5 wages;
	collapse (sum) wages wages_rec, by(round villageid hhn id);
	sort hhn id;
	save "`tmppath'/OthIncP2.dta", replace;

	use "`rpath'/OthIncP3.dta", clear;
	sort hhn id;
	for var c_q3 c_q4 c_q5 d_q2: replace X = . if X==99 | X==999;
	ren c_q3 othf_rev;
	ren c_q4 othf_exp;
	ren c_q5 othf_prof;
	ren d_q2 oth_inc;
	collapse (sum) othf_rev othf_exp othf_prof oth_inc, by(round villageid hhn id);
	sort hhn id;
	save "`tmppath'/OthIncP3.dta", replace;

	merge hhn id using "`tmppath'/OthIncP2.dta"; drop _m;
	sort hhn id;
	merge hhn id using "`tmppath'/OthIncP1.dta"; drop _m;
	sort hhn id;
	save "`spath'/OthInc.dta", replace;

	merge hhn id using "`spath'/SaleFmOut.dta"; drop _m;

	replace round = `round' if round==.;
	replace villageid = `ii' if villageid==.;
	for var _all: recode X .=0;

	order round villageid hhn id;
	sort hhn id;
	save "`spath'/Income.dta", replace;

	/* Gifts and Transfers */
	use "`rpath'/GiftsP1.dta", clear;
	replace q5 = . if q5==99 | q5==999;
	gen gifts_cash = q5 if gave==1; recode gifts_cash .=0;
	gen vill_gifts_cash = gifts_cash if q3<=4 & q3!=.; recode vill_gifts_cash .=0;
	gen receipts_cash = q5 if gave==0; recode receipts_cash .=0;
	gen vill_receipts_cash = receipts_cash if q3<=4 & q3!=.; recode vill_receipts_cash .=0;
	sort hhn id;
	collapse (sum) gifts_cash receipts_cash vill_gifts_cash vill_receipts_cash, by(round villageid hhn id);
	sort hhn id;
	save "`tmppath'/GiftsP1.dta", replace;

	use "`rpath'/GiftsP2.dta", clear;
	replace q5v = . if q5v==99 | q5v==999;
	gen gifts_kind = q5v if gave==1; recode gifts_kind .=0;
	gen vill_gifts_kind = gifts_kind if q3<=4 & q3!=.; recode vill_gifts_kind .=0;
	gen receipts_kind = q5v if gave==0; recode receipts_kind .=0;
	gen vill_receipts_kind = receipts_kind if q3<=4 & q3!=.; recode vill_receipts_kind .=0;
	sort hhn id;
	collapse (sum) gifts_kind receipts_kind vill_gifts_kind vill_receipts_kind, by(round villageid hhn id);
	sort hhn id;
	save "`tmppath'/GiftsP2.dta", replace;

	merge hhn id using "`tmppath'/GiftsP1.dta"; drop _m;
	sort hhn id;
	for var gifts_cash vill_gifts_cash receipts_cash vill_receipts_cash gifts_kind vill_gifts_kind receipts_kind vill_receipts_kind: recode X .=0;
	gen gifts = gifts_cash + gifts_kind;
	gen vill_gifts = vill_gifts_cash + vill_gifts_kind;
	gen receipts = receipts_cash + receipts_kind;
	gen vill_receipts = vill_receipts_cash + vill_receipts_kind;
	order round villageid hhn id gifts receipts gifts_cash gifts_kind receipts_cash receipts_kind
			vill_gifts vill_receipts vill_gifts_cash vill_gifts_kind vill_receipts_cash vill_receipts_kind;
	save "`spath'/Gifts.dta", replace;

	/* Interhousehold transfers */
	use "`rpath'/GiftsP3.dta", clear;
	for var q2* q3* q4?a q10?a: replace X = 0 if X==. \ replace X = . if X==99 | X==999;
	egen chop_curr = rsum(q3a q3b q3c q3d q3e q3f q3g);		* Chop money ;
	egen chop_norm = rsum(q2a q2b q2c q2d q2e q2f q2g);
	egen gift_cash = rsum(q4aa q4ba q4ca q4da q4ea q4fa q4ga);
	egen gift_kind = rsum(q8aa q8ba q8ca q8da q8ea q8fa q8ga q8ha q8ia q8ja);
	egen gift_bus = rsum(q10aa q10ba q10ca q10da q10ea q10fa q10ga q10ha q10ia q10ja);
	* Change sign if it's husband, to reflect gift rather than receipt ;
	replace chop_curr = -chop_curr if id==100;
	replace chop_norm = -chop_norm if id==100;
	replace gift_cash = -gift_cash if id==100;
	replace gift_kind = -gift_kind if id==100;
	replace gift_bus = -gift_bus if id==100;

	egen intrahh = rsum(chop_curr chop_norm gift_cash gift_kind gift_bus);
	keep round villageid hhn id intrahh chop_curr chop_norm gift_cash gift_kind gift_bus;
	sort hhn id;
	save "`spath'/Intrahousehold.dta", replace;

	/* Loans and Borrowing */
	if `round'>1 {;
		use "`rpath'/LendingCont.dta", clear;
		qui destring q7 q12, replace;
		for var q7 q12: replace X = . if X==99 | X==999;
		gen repayment = q7;
		recode repayment .=0;
		gen instalment = q12;
		recode instalment .=0;
		gen net_loan = instalment - repayment;
		sort hhn id;
		collapse (sum) net_loan, by(round villageid hhn id);
		sort hhn id;
		save "`tmppath'/LendingCont.dta", replace;

		use "`rpath'/BorrowingCont.dta", clear;
		* Skip if questionnaire is empty ;
		qui describe;
		local nobs = r(N);
		* If the questionnaire is nonempty, use it ;
		if `nobs'>0 {;
			qui destring q7 q12, replace;
			for var q7 q12: replace X = . if X==99 | X==999;
			gen repayment = q7;
			recode repayment .=0;
			gen instalment = q12;
			recode instalment .=0;
			gen net_borrow = instalment - repayment;
			sort hhn id;
			collapse (sum) net_borrow, by(round villageid hhn id);
			sort hhn id;
			save "`tmppath'/BorrowingCont.dta", replace;
		
			merge hhn id using "`tmppath'/LendingCont.dta";
			drop _m;
			for var net_loan net_borrow: recode X .=0;
			gen net_flow = net_borrow - net_loan;			* Net inflow of funds ;
			keep round villageid hhn id net_flow net_loan net_borrow;
			sort hhn id;
			save "`spath'/LoanCont.dta", replace;
		};
		* Otherwise, skip borrowing continuation ;
		else {;
			use "`tmppath'/LendingCont.dta", clear;
			gen net_borrow = 0;
			gen net_flow = -net_loan;				* Net outflow of funds, just loans b/c no borrowing ;
			keep round villageid hhn id net_flow net_loan net_borrow;
			sort hhn id;
			save "`spath'/LoanCont.dta", replace;
		};
	};
	use "`rpath'/Lending.dta", clear;
	gen lent = q7 if q10==2;
	recode lent .=0;
	replace lent = . if lent==99 | lent==999;
	sort hhn id;
	collapse (sum) lent, by(round villageid hhn id);
	sort hhn id;
	save "`tmppath'/Lending.dta", replace;

	use "`rpath'/Borrowing.dta", clear;
	gen borrowed = q7 if q10==2;
	recode borrowed .=0;
	replace borrowed = . if borrowed==99 | borrowed==999;
	sort hhn id;
	collapse (sum) borrowed, by(round villageid hhn id);
	sort hhn id;
	save "`tmppath'/Borrowing.dta", replace;

	merge hhn id using "`tmppath'/Lending.dta"; drop _m;
	for var borrowed lent: recode X .=0;
	order round villageid hhn id borrowed lent;
	sort hhn id;
	if `round'>1 {;
		merge hhn id using "`spath'/LoanCont.dta";
		drop _m;
		for var borrowed lent net_flow net_loan net_borrow: recode X .=0;
		sort hhn id;
	};
	else {;
		gen net_flow = 0;
		gen net_loan = 0;
		gen net_borrow = 0;
		for var borrowed lent: recode X .=0;
	};
	save "`spath'/Loans.dta", replace;


	/* Construct aggregate inflows (net cash income) */
	* Income ;
	use "`spath'/Income.dta", clear;
	egen income = rsum(othf_prof oth_inc wages_rec bus_profit farm_sales1 farm_sales2);
	sort hhn id;
	keep round villageid hhn id income;
	save "`tmppath'/Income_Net.dta", replace;

	* Gifts and transfers ;
	use "`spath'/Gifts.dta", clear;
	gen netgift = gifts - receipts;
	keep round villageid hhn id netgift;
	sort hhn id;
	merge hhn id using "`tmppath'/Income_Net.dta"; drop _m;
	sort hhn id;
	save "`tmppath'/Income_Net.dta", replace;

	* Interhousehold transfers ;
	use "`spath'/Intrahousehold.dta", clear;
	keep round villageid hhn id intrahh;
	sort hhn id;
	merge hhn id using "`tmppath'/Income_Net.dta"; drop _m;
	sort hhn id;
	save "`tmppath'/Income_Net.dta", replace;

	* Loans ;
	merge hhn id using "`spath'/Loans.dta"; drop _m;
	sort hhn id;
	save "`spath'/Income_Net.dta", replace;
	
	/* Generate household aggregates */
	collapse (sum) intrahh netgift income borrowed lent net_flow net_loan net_borrow, by(round villageid hhn);
	gen netinc = income - netgift - lent + borrowed + net_flow;
	sort hhn;
	save "`spath'/HHIncome.dta", replace;

	erase "`tmppath'/Income_Net.dta";
	
	/* Organizations and Cooperatives */
	if `round'==2 {;
	
		* Organizations ;
		use "`rawpath'/Round 2/Stata//`village'//Organizations.dta", clear;	
		* Clean up group types so they can be categorised ;
		replace q2 = upper(q2);
		replace q2 = "FUNERAL ORGANIZATION" if index(q2,"FUNERAL") | index(q2,"BURIAL");
		replace q2 = "CHURCH ORGANIZATION" if index(q2,"CHURCH") | index(q2,"FELLOWSHIP") | index(q2,"RELIGIOUS");
		replace q2 = "YOUTH ASSOCIATION" if index(q2,"YOUTH");
		replace q2 = "WELFARE GROUP" if index(q2,"WELFARE") | index(q2,"ASSISTANCE");
		replace q2 = "FARMING ORGANIZATION" if index(q2,"FARMING") | index(q2,"FARMER");
		replace q2 = "SUPPORT GROUP" if index(q2,"SUPPORT");
		save "`spath'/Organizations.dta", replace;
		
		* Cooperatives ;
		use "`rawpath'/Round 2/Stata//`village'//Cooperatives.dta", clear;
		
		* Get start date to measure length of participation ;
		replace q5="" if q5=="99/99";
		gen q5len = length(q5);
		gen str2 mth = substr(q5,1,2) if q5len>1;
		destring mth, gen(month); drop mth;
		gen str2 yr = substr(q5,4,2) if q5len>1;
		destring yr, gen(year); drop yr;
		replace year = 1900+year if year>=30 & year!=.;
		replace year = 2000+year if year<30 & year!=.;
		replace month = 6 if month==0 | month==99;
		gen coop_tenure = 12*(2009-year) + (month-5);
		replace coop_tenure=. if q8!="";
		replace coop_tenure = 0 if coop_tenure < 0;
		keep villageid hhn id coop_tenure;
		label var coop_tenure "Time as member of cooperative";
		sort hhn id;
		save "`spath'/Cooperatives.dta", replace;
	};	


	local ii = `ii' + 1;
};


